==> mockspace-0.1.1.tar.gz: mockspace-0.1.1/README.md <==
# mockspace
[![Build Status][travis-image]][travis-url]
[![License][License-image]][License-url]
[![Status][Status-image]][Status-url]


## About

``mockspace`` is a tool that provides a convenient interface for quickly creating a mock environment:
add web-services, fill them with the methods you need and configure response parameters.

## Installation

To install mockspace, run this command in your terminal:

```sh
pip install mockspace
```

## Launching

To start mockspace, run the following command:

```sh
mockspace
```

and go to http://localhost:8080.

## Usage

#### Add the necessary web-services

<img width="580" alt="screen shot 2018-07-14 at 6 22 58 pm" src="https://raw.githubusercontent.com/mockspace/mockspace.github.io/master/files/services.png">

#### Fill a web-services with methods you need

<img width="580" alt="screen shot 2018-07-14 at 6 22 58 pm" src="https://raw.githubusercontent.com/mockspace/mockspace.github.io/master/files/userinfo.png">

#### Configure response parameters

<img width="580" alt="screen shot 2018-07-14 at 6 22 58 pm" src="https://raw.githubusercontent.com/mockspace/mockspace.github.io/master/files/method_options.png">

## License

[MIT](LICENSE)

<!-- Markdown link & img dfn's -->
[travis-image]: https://travis-ci.org/github/mockspace/mockspace.svg?branch=master
[travis-url]: https://travis-ci.org/github/mockspace/mockspace
[wiki]: https://github.com/yourname/yourproject/wiki
[License-image]: https://img.shields.io/pypi/l/mockspace.svg
[License-url]: https://github.com/mockspace/mockspace/blob/master/LICENSE
[Status-image]: https://img.shields.io/pypi/status/mockspace.svg
[Status-url]: https://pypi.org/project/mockspace/

==> mockspace-0.1.3.tar.gz: mockspace-0.1.3/README.md <==
# mockspace
[![Pypi][PyPI-image]][PyPI-url]
[![License][License-image]][License-url]
[![Status][Status-image]][Status-url]


## About

``mockspace`` is a tool that provides a convenient interface for quickly creating a mock environment:
add web-services, fill them with the methods you need and configure response parameters.

## Installation

To install mockspace, run this command in your terminal:

```sh
pip install mockspace
```

## Launching

To start mockspace, run the following command:

```sh
mockspace
```

and go to http://localhost:8080.

## Usage

#### Add the necessary web-services

<img width="580" alt="screen shot 2018-07-14 at 6 22 58 pm" src="https://raw.githubusercontent.com/mockspace/mockspace.github.io/master/files/services.png">

#### Fill a web-services with methods you need

<img width="580" alt="screen shot 2018-07-14 at 6 22 58 pm" src="https://raw.githubusercontent.com/mockspace/mockspace.github.io/master/files/userinfo.png">

#### Configure response parameters

<img width="580" alt="screen shot 2018-07-14 at 6 22 58 pm" src="https://raw.githubusercontent.com/mockspace/mockspace.github.io/master/files/method_options.png">

## License

[MIT](LICENSE)

<!-- Markdown link & img dfn's -->
[PyPI-image]: https://img.shields.io/pypi/v/mockspace
[PyPI-url]: https://img.shields.io/pypi/v/mockspace
[wiki]: https://github.com/yourname/yourproject/wiki
[License-image]: https://img.shields.io/pypi/l/mockspace.svg
[License-url]: https://github.com/mockspace/mockspace/blob/master/LICENSE
[Status-image]: https://img.shields.io/pypi/status/mockspace.svg
[Status-url]: https://pypi.org/project/mockspace/
